@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ABSTRACTSELECTEMAILLINEEDIT_H
-#define ABSTRACTSELECTEMAILLINEEDIT_H
+#pragma once
 
-#include <QWidget>
 #include "ksieveui_export.h"
-namespace KSieveUi {
+#include <QWidget>
+namespace KSieveUi
+{
 /**
  * @brief The AbstractSelectEmailLineEdit class
  * @author Laurent Montel <montel@kde.org>
@@ -19,7 +19,7 @@ class KSIEVEUI_EXPORT AbstractSelectEmailLineEdit : public QWidget
     Q_OBJECT
 public:
     explicit AbstractSelectEmailLineEdit(QWidget *parent = nullptr);
-    ~AbstractSelectEmailLineEdit();
+    ~AbstractSelectEmailLineEdit() override;
     virtual void setText(const QString &str) = 0;
     virtual QString text() const = 0;
 
@@ -29,9 +29,9 @@ public:
 
 Q_SIGNALS:
     void valueChanged();
+
 private:
     bool mMultiSelection = false;
 };
 }
 
-#endif // ABSTRACTSELECTEMAILLINEEDIT_H
